@@ -18,13 +18,15 @@ labkey.insertRows <- function(baseUrl=NULL, folderPath, schemaName, queryName, t
 {  
     baseUrl=labkey.getBaseUrl(baseUrl)
 
+    ## Validate required parameters
+    if (missing(folderPath)) stop (paste("A value must be specified for folderPath."))
+    if (missing(schemaName)) stop (paste("A value must be specified for schemaName."))
+    if (missing(queryName)) stop (paste("A value must be specified for queryName."))
+    if (missing(toInsert)) stop (paste("A value must be specified for toInsert."))
+
     ## Default showAllRows=TRUE
     showAllRows=TRUE
 
-    ## Error if any of baseUrl, folderPath, schemName or toInsert are missing
-    if(missing("baseUrl") || is.null(baseUrl) || missing("folderPath") || missing("schemaName") || missing("toInsert"))
-        stop (paste("A value must be specified for each of baseUrl, folderPath, schemaName and toInsert."))
-
     ## normalize the folder path
     folderPath <- encodeFolderPath(folderPath)
 
